<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="evalStartDate" label="评价开始时间">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.evalStartDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="evalEndDate" label="评价结束时间">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.evalEndDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="deliver" label="机构评价负责人">
            <el-input
                v-model="state.formData.deliver"
                size="large"
                placeholder="请选择机构评价负责人"
            >
              <template #append>
                <el-button :icon="Search" @click="openExperts('机构评价负责人')"/>
              </template>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="deliver" label="技术负责人">
            <el-input
                v-model="state.formData.deliver"
                size="large"
                placeholder="请选择技术负责人"
            >
              <template #append>
                <el-button :icon="Search" @click="openExperts('技术负责人')"/>
              </template>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-table  :data="state.tableData" :border="true" style="margin: 20px 0">
        <el-table-column label="序号" width="60" align="center" type="index"></el-table-column>
        <el-table-column label="评价日程安排" prop="content" header-align="center" :show-overflow-tooltip="true"/>
        <el-table-column label="开始时间" header-align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-date-picker
                style="width: 100%"
                v-model="scope.row.startDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </template>
        </el-table-column>
        <el-table-column label="结束时间" header-align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-date-picker
                style="width: 100%"
                v-model="scope.row.endDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </template>
        </el-table-column>
      </el-table>
    </el-form>
    <experts-list ref="expertsListRef" @getName="getSelected"></experts-list>
  </div>
</template>
<script setup>

import {defineEmits, onMounted, reactive, ref} from "vue"
import {ElMessage} from "element-plus"
import {Search} from '@element-plus/icons-vue'
import {addRisk, editRisk, getRiskDetail} from "@/api/projectManage/riskAnalysis"
import Cookies from "js-cookie"
import ExpertsList from "./expertsList"
const emit = defineEmits(["getNextStatus"])

const state = reactive({
  formData: {
    project: {
      id: '',

    },
    id: ''
  },
  rules: {
    "project.name": [{required: true, message: '请填写项目名称', trigger: 'blur'}],
    riskCharacter: [{required: true, message: '请填写行业风险特性', trigger: 'blur'}],
  },
  tableData: [
    {
      id: '1',
      content: '勘验准备',
      status: 1
    },
    {
      id: '2',
      content: '现场勘验',
      status: 1
    },
    {
      id: '3',
      content: '材料分析整理',
      status: 1
    },
    {
      id: '4',
      content: '评价报告编写',
      status: 1
    },
    {
      id: '5',
      content: '整改情况现场确认',
      status: 1
    },
    {
      id: '6',
      content: '整理评价报告',
      status: 1
    },
    {
      id: '7',
      content: '报告审核',
      status: 1
    },
    {
      id: '8',
      content: '报告修改',
      status: 1
    },
  ]
})
const props = {
  expandTrigger: 'hover',
  value: 'name',
  label: 'name'
}
const isAmin = ref(false)
const formRef = ref()
const expertsListRef = ref()
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
});

const riskOpen = async (type,val) => {
  console.log("type",type,val)
  if(type === 'detail' || type === 'edit' ){
    const res = await getRiskDetail({projectId: val});
    if(res.code == 200){
      state.formData = res.data;
      state.formData.project.business = parseInt(res.data.project.business);
      state.formData.project.area = [res.data.project.province,res.data.project.city];
      state.tableData[0].status = res.data.isInBusiness ? 1 : 0;
      state.tableData[1].status = res.data.isSatisfyNeed ? 1 : 0;
      state.tableData[2].status = res.data.isNeedExpert ? 1 : 0;
      state.tableData[3].status = res.data.isFinishReport ? 1 : 0;
      state.tableData[4].status = res.data.isAcceptChargess ? 1 : 0;
      state.tableData[5].status = res.data.isFeasibility ? 1 : 0;
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      if(type === 'add'){
        const {id, ...data} = JSON.parse(JSON.stringify(state.formData))
        delete data.project.area;
        delete data.project.id;
        data.isInBusiness = state.tableData[0].status === 1;
        data.isSatisfyNeed = state.tableData[1].status === 1;
        data.isNeedExpert = state.tableData[2].status === 1;
        data.isFinishReport = state.tableData[3].status === 1;
        data.isAcceptChargess = state.tableData[4].status === 1;
        data.isFeasibility = state.tableData[5].status === 1;
        console.log('data', data)
        const res = await addRisk(data);
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', res.data);

        } else {
          ElMessage.warning(res.message)
        }
      }else if(type === 'clickEdit'){
        const { ...data} = JSON.parse(JSON.stringify(state.formData))
        delete data.project.area;
        data.isInBusiness = state.tableData[0].status === 1;
        data.isSatisfyNeed = state.tableData[1].status === 1;
        data.isNeedExpert = state.tableData[2].status === 1;
        data.isFinishReport = state.tableData[3].status === 1;
        data.isAcceptChargess = state.tableData[4].status === 1;
        data.isFeasibility = state.tableData[5].status === 1;
        console.log('data', data)
        const res = await editRisk(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

const openExperts = (type) =>{
  expertsListRef.value.openDialog(type)
}

const getSelected = (type,obj)=>{
  if(type == '项目负责人'){
    state.formData.project.leader = obj.name
  }
  if(type == '任务下达人'){
    state.formData.deliver = obj.name
  }
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
